pub struct SocketCanChannelBuilder { /* private fields */ }Expand description
Builder for opening a SocketCAN channel.
SocketCAN bitrate is OS-managed, so this builder only chooses the interface - there are deliberately no methods to set bitrate, sample point, or FD timing.
Implementations
Sourceimpl SocketCanChannelBuilder
impl SocketCanChannelBuilder
Sourcepub fn connect(self) -> Result<SocketCanChannel, SocketCanError>
pub fn connect(self) -> Result<SocketCanChannel, SocketCanError>
Open the channel and go on-bus.